%define upstream_name    MooseX-NonMoose
%define upstream_version 0.26

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 9

Summary:    Constructor method trait for L<MooseX::NonMoose>
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        http://search.cpan.org/dist/%{upstream_name}
Source0:    http://www.cpan.org/modules/by-module/MooseX/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker) >= 6.300.0
BuildRequires: perl(File::Spec)
BuildRequires: perl(IO::Handle)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(List::MoreUtils)
BuildRequires: perl(Module::Runtime)
BuildRequires: perl(Moose)
BuildRequires: perl(Moose::Exporter)
BuildRequires: perl(Moose::Role) >= 2.0.0
BuildRequires: perl(Moose::Util)
BuildRequires: perl(Test::Fatal)
BuildRequires: perl(Test::Moose)
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(Try::Tiny)
BuildRequires: perl(base)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%{?perl_default_filter}

%description
'MooseX::NonMoose' allows for easily subclassing non-Moose classes with
Moose, taking care of the annoying details connected with doing this, such
as setting up proper inheritance from the Moose::Object manpage and
installing (and inlining, at 'make_immutable' time) a constructor that
makes sure things like 'BUILD' methods are called. It tries to be as
non-intrusive as possible - when this module is used, inheriting from
non-Moose classes and inheriting from Moose classes should work
identically, aside from the few caveats mentioned below. One of the goals
of this module is that including it in a the Moose::Exporter manpage-based
package used across an entire application should be possible, without
interfering with classes that only inherit from Moose modules, or even
classes that don't inherit from anything at all.

There are several ways to use this module. The most straightforward is to
just 'use MooseX::NonMoose;' in your class; this should set up everything
necessary for extending non-Moose modules. the
MooseX::NonMoose::Meta::Role::Class manpage and the
MooseX::NonMoose::Meta::Role::Constructor manpage can also be applied to
your metaclasses manually, either by passing a '-traits' option to your
'use Moose;' line, or by applying them using the Moose::Util::MetaRole
manpage in a the Moose::Exporter manpage-based package. the
MooseX::NonMoose::Meta::Role::Class manpage is the part that provides the
main functionality of this module; if you don't care about inlining, this
is all you need to worry about. Applying the
MooseX::NonMoose::Meta::Role::Constructor manpage as well will provide an
inlined constructor when you immutabilize your class.

'MooseX::NonMoose' allows you to manipulate the argument list that gets
passed to the superclass constructor by defining a 'FOREIGNBUILDARGS'
method. This is called with the same argument list as the 'BUILDARGS'
method, but should return a list of arguments to pass to the superclass
constructor. This allows 'MooseX::NonMoose' to support superclasses whose
constructors would get confused by the extra arguments that Moose requires
(for attributes, etc.)

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make

%check
%make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*


%changelog
* Wed Feb 12 2020 umeabot <umeabot> 0.260.0-9.mga8
+ Revision: 1495679
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.260.0-8.mga7
+ Revision: 1269611
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.260.0-7.mga6
+ Revision: 1030501
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.260.0-6.mga6
+ Revision: 948772
- Mageia 6 Mass Rebuild

* Sat Oct 18 2014 umeabot <umeabot> 0.260.0-5.mga5
+ Revision: 788361
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.260.0-4.mga5
+ Revision: 749211
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tv <tv> 0.260.0-3.mga5
+ Revision: 735847
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.260.0-2.mga5
+ Revision: 685552
- Mageia 5 Mass Rebuild

* Fri Feb 28 2014 jquelin <jquelin> 0.260.0-1.mga5
+ Revision: 597889
- update to 0.26

* Mon Feb 10 2014 jquelin <jquelin> 0.250.0-1.mga5
+ Revision: 588543
- update to 0.25

* Sat Oct 19 2013 umeabot <umeabot> 0.240.0-2.mga4
+ Revision: 534060
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 sander85 <sander85> 0.240.0-1.mga4
+ Revision: 476142
- update to 0.24

* Sun Jan 13 2013 umeabot <umeabot> 0.220.0-2.mga3
+ Revision: 370209
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jun 15 2011 jquelin <jquelin> 0.220.0-1.mga2
+ Revision: 107140
- update to 0.22

* Thu Mar 24 2011 jquelin <jquelin> 0.200.0-1.mga1
+ Revision: 76656
- update to 0.20

* Wed Mar 09 2011 jquelin <jquelin> 0.190.0-1.mga1
+ Revision: 67002
- update to 0.19

* Wed Feb 16 2011 jquelin <jquelin> 0.180.0-1.mga1
+ Revision: 52596
- update to 0.18

* Thu Jan 27 2011 jquelin <jquelin> 0.170.0-1.mga1
+ Revision: 41870
- imported package perl-MooseX-NonMoose


* Thu Jan 27 2011 cpan2dist 0.17-1mdv
- initial mdv release, generated with cpan2dist
